
function DoesIntersect( CurveA, CurveB )
{
	var list = moi.geometryDatabase.createObjectList();
	list.addObject( CurveA );
	list.addObject( CurveB );

	var factory = moi.command.createFactory( 'intersect' );
	factory.setInput( 0, list );

	if ( factory.noCurveFrom2Views != undefined )
		factory.noCurveFrom2Views = true;

	var result = factory.calculate();
	factory.cancel();

	return (result.numPoints > 0);
}

function GetIntersected( swipe_polyline )
{
	if ( !swipe_polyline.isPlanar )
		return;

	var swipe_plane = swipe_polyline.planarFrame;

	var output_list = moi.geometryDatabase.createObjectList();
	var objects = moi.geometryDatabase.getObjects().getCurves();

	for ( var i = 0; i < objects.length; ++i )
	{
		var obj = objects.item( i );
		if ( obj.id == swipe_polyline.id || obj.hidden || obj.locked )
			continue;

		if ( !obj.isOnPlane( swipe_plane ) )
			continue;

		if ( DoesIntersect( swipe_polyline, obj ) )
			output_list.addObject( obj );
	}

	return output_list;
}

function ApplyQuickTrim( swipe_polyline )
{
	var using_selected = true;
	var target_curves = moi.geometryDatabase.getSelectedObjects().getCurves();
	if ( target_curves.length == 0 )
	{
		using_selected = false;
		target_curves = moi.geometryDatabase.getObjects().getCurves();
	}

	if ( target_curves.length == 0 )
		return;

	var trim_factory = moi.command.createFactory( 'trim' );
	trim_factory.setInput( 0, target_curves ); // Objects to be cut.
	trim_factory.setInput( 1, target_curves ); // Cutting objects.
	trim_factory.setInput( 3, 'remove' ); // Mode for "remove" or "keep".
	trim_factory.setInput( 4, false );    // True = extend lines.
	trim_factory.setInput( 5, false );    // True = use projected intersections.

	if ( trim_factory.allowDeleteWholeCurve != undefined )
		trim_factory.allowDeleteWholeCurve = true;

	trim_factory.generateFragments();

	var fragments = GetIntersected( swipe_polyline );
	trim_factory.setInput( 2, fragments );

	trim_factory.finishedPickingFragments();
	trim_factory.update();

	if ( using_selected )
	{
		trim_factory.getCreatedObjects().setProperty( 'selected', true );
		target_curves.setProperty( 'selected', true );
	}

	trim_factory.commit();
}

function DoQuickTrim()
{
	var pointstreampicker = moi.ui.createPointStreamPicker();
	var swipe_factory = moi.command.createFactory( 'polyline' );

	pointstreampicker.bind( swipe_factory );
	
	while ( 1 )
	{
		if ( !pointstreampicker.waitForEvent() )
			return;

		if ( pointstreampicker.event == 'done' )
			return;
			
		if ( pointstreampicker.event == 'finished' )
			break;
	}
		
	var swipe_list = swipe_factory.calculate();
	swipe_factory.cancel();

	if ( swipe_list.length == 1 )
	{
		var swipe_polyline = swipe_list.item( 0 );
		ApplyQuickTrim( swipe_polyline );
	}
}

DoQuickTrim();
